=====================
Djblets Documentation
=====================

.. toctree::
   :maxdepth: 3

   guides/index
   coderef/index


Indices, glossary and tables
============================

* :ref:`tableofcontents`
* :ref:`genindex`
